from setuptools import setup
setup(name='SURPY',
version='1.1.2',
description='SURPY python for  surgical data analysis',
url='https://github.com/sasurasa/Surgical-Outcome-Analysis-on-Python/tree/SURG-package',
author='Surasak Sangkhathat',
author_email='s.sangkhathat@gmail.com',
license='Prince of Songkla University',
packages=['SURPY'],
zip_safe=False)